==> prestashop_1.4.0.17.zip: prestashop/modules/sekeywords/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{sekeywords}prestashop>sekeywords_65b0b42febc8ea16db4652eab6f420a4'] = 'Suchmaschinen-Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_de13be6263895a5efe4d51e15ab1535e'] = 'Anzeigen, durch welche Keywords Besucher Ihre Webseite gefunden haben';
$_MODULE['<{sekeywords}prestashop>sekeywords_a6a5cc2d3979e54597c79a68448adee2'] = 'Keyword, das Ihrer Abfrage entspricht.';
$_MODULE['<{sekeywords}prestashop>sekeywords_abc9f128fb01c8504e08e77bfc8af795'] = 'Keywords, die Ihrer Abfrage entsprechen.';
$_MODULE['<{sekeywords}prestashop>sekeywords_867343577fa1f33caa632a19543bd252'] = 'Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_e52e6aa1a43a0187e44f048f658db5f9'] = 'Vorkommen';
$_MODULE['<{sekeywords}prestashop>sekeywords_998e4c5c80f27dec552e99dfed34889a'] = 'CSV-Export';
$_MODULE['<{sekeywords}prestashop>sekeywords_0849140171616600e8f2c35f0a225212'] = 'Filtern nach Keyword';
$_MODULE['<{sekeywords}prestashop>sekeywords_188ef1f71ff3ef1c5501dc5c8ee27f88'] = 'und Mindestvorkommen';
$_MODULE['<{sekeywords}prestashop>sekeywords_03e0e9ef8b776b5f7bcc590e51bfa63b'] = 'Anwenden';
$_MODULE['<{sekeywords}prestashop>sekeywords_7b48f6cc4a1dde7fca9597e717c2465f'] = 'Keine Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{sekeywords}prestashop>sekeywords_39f040a1f174811285297763fcaada12'] = 'Externe Suchmaschinen-Keywords identifizieren';
$_MODULE['<{sekeywords}prestashop>sekeywords_f4e8acc0e0cfc0653d6354c3ef878d29'] = 'Es gibt viele Möglichkeiten, eine Webseite zu finden, aber eine der häufigsten ist es, sie mit einer Suchmaschine zu finden. Die Ermittlung der Keywords, die die meisten Besucher anlocken, ist daher von großer Bedeutung. Dadurch können Sie erkennen, welches Produkt Sie hervorheben müssen, um mehr Besucher und Kunden zu haben.';
$_MODULE['<{sekeywords}prestashop>sekeywords_359f9e79e746fa9f684e5cda9e60ca2e'] = 'Wie funktioniert das?';
$_MODULE['<{sekeywords}prestashop>sekeywords_b20af255c34d0a4ace56863dbd8f0c90'] = 'Wenn ein Besucher auf Ihre Webseite kommt, kennt der Server ihre davorige Seite. Dieses Modul analysiert diese URL und findet die in ihr enthaltenen Keywords. Derzeit verwaltet es die folgende Suchmaschinen:';
$_MODULE['<{sekeywords}prestashop>sekeywords_be5d5d37542d75f93a87094459f76678'] = 'und';
$_MODULE['<{sekeywords}prestashop>sekeywords_474c03326cba5cb2ce6c07ddf3e1e656'] = 'Bald wird es möglich sein, eine neue Suchmaschine dynamisch hinzufügen und zu diesem Modul beizutragen!';
$_MODULE['<{sekeywords}prestashop>sekeywords_8d01ac22a68176ddd7067da99508751d'] = '10 erste Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_52ef9633d88a7480b3a938ff9eaa2a25'] = 'Weitere';

==> prestashop_1.4.3.0.zip: prestashop/modules/sekeywords/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{sekeywords}prestashop>sekeywords_65b0b42febc8ea16db4652eab6f420a4'] = 'Suchmaschinen-Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_de13be6263895a5efe4d51e15ab1535e'] = 'Anzeigen, durch welche Keywords Besucher Ihre Webseite gefunden haben';
$_MODULE['<{sekeywords}prestashop>sekeywords_a6a5cc2d3979e54597c79a68448adee2'] = 'Keyword, das Ihrer Abfrage entspricht.';
$_MODULE['<{sekeywords}prestashop>sekeywords_abc9f128fb01c8504e08e77bfc8af795'] = 'Keywords, die Ihrer Abfrage entsprechen.';
$_MODULE['<{sekeywords}prestashop>sekeywords_867343577fa1f33caa632a19543bd252'] = 'Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_e52e6aa1a43a0187e44f048f658db5f9'] = 'Vorkommen';
$_MODULE['<{sekeywords}prestashop>sekeywords_998e4c5c80f27dec552e99dfed34889a'] = 'CSV-Export';
$_MODULE['<{sekeywords}prestashop>sekeywords_0849140171616600e8f2c35f0a225212'] = 'Filtern nach Keyword';
$_MODULE['<{sekeywords}prestashop>sekeywords_188ef1f71ff3ef1c5501dc5c8ee27f88'] = 'und Mindestvorkommen';
$_MODULE['<{sekeywords}prestashop>sekeywords_03e0e9ef8b776b5f7bcc590e51bfa63b'] = 'Anwenden';
$_MODULE['<{sekeywords}prestashop>sekeywords_7b48f6cc4a1dde7fca9597e717c2465f'] = 'Keine Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_6602bbeb2956c035fb4cb5e844a4861b'] = 'Erklärung';
$_MODULE['<{sekeywords}prestashop>sekeywords_39f040a1f174811285297763fcaada12'] = 'Externe Suchmaschinen-Keywords identifizieren';
$_MODULE['<{sekeywords}prestashop>sekeywords_f4e8acc0e0cfc0653d6354c3ef878d29'] = 'Es gibt viele Möglichkeiten, eine Webseite zu finden, aber eine der häufigsten ist es, sie mit einer Suchmaschine zu finden. Die Ermittlung der Keywords, die die meisten Besucher anlocken, ist daher von großer Bedeutung. Dadurch können Sie erkennen, welches Produkt Sie hervorheben müssen, um mehr Besucher und Kunden zu haben.';
$_MODULE['<{sekeywords}prestashop>sekeywords_359f9e79e746fa9f684e5cda9e60ca2e'] = 'Wie funktioniert das?';
$_MODULE['<{sekeywords}prestashop>sekeywords_b20af255c34d0a4ace56863dbd8f0c90'] = 'Wenn ein Besucher auf Ihre Webseite kommt, kennt der Server ihre davorige Seite. Dieses Modul analysiert diese URL und findet die in ihr enthaltenen Keywords. Derzeit verwaltet es die folgende Suchmaschinen:';
$_MODULE['<{sekeywords}prestashop>sekeywords_be5d5d37542d75f93a87094459f76678'] = 'und';
$_MODULE['<{sekeywords}prestashop>sekeywords_474c03326cba5cb2ce6c07ddf3e1e656'] = 'Bald wird es möglich sein, eine neue Suchmaschine dynamisch hinzufügen und zu diesem Modul beizutragen!';
$_MODULE['<{sekeywords}prestashop>sekeywords_8d01ac22a68176ddd7067da99508751d'] = '10 erste Keywords';
$_MODULE['<{sekeywords}prestashop>sekeywords_52ef9633d88a7480b3a938ff9eaa2a25'] = 'Weitere';

?>
